# cPyparsing

[Cython](http://cython.org/) implementation of [PyParsing](http://pyparsing.wikispaces.com/) created for use in [Coconut](http://coconut-lang.org/) and [Undebt](https://github.com/Yelp/undebt).

Just `pip install cpyparsing` then `import cPyparsing as pyparsing` or otherwise use `cPyparsing` however you would normally use `pyparsing`.

`cPyparsing` supports Python `2.6+` on the Python 2 branch and Python `3.3+` on the Python 3 branch.
